@@ -625,7 +625,7 @@ impl ShellError {
             }
 
             ProximateShellError::UntaggedRuntimeError { reason } => Diagnostic::error().with_message(format!("Error: {}", reason)),
-            ProximateShellError::Unimplemented { reason } => Diagnostic::error().with_message(format!("Inimplemented: {}", reason)),
+            ProximateShellError::Unimplemented { reason } => Diagnostic::error().with_message(format!("Unimplemented: {}", reason)),
 
         };
 
@@ -871,25 +871,25 @@ impl std::error::Error for ShellError {}
 
 impl std::convert::From<Box<dyn std::error::Error>> for ShellError {
     fn from(input: Box<dyn std::error::Error>) -> ShellError {
-        ShellError::untagged_runtime_error(format!("{}", input))
+        ShellError::untagged_runtime_error(input.to_string())
     }
 }
 
 impl std::convert::From<std::io::Error> for ShellError {
     fn from(input: std::io::Error) -> ShellError {
-        ShellError::untagged_runtime_error(format!("{}", input))
+        ShellError::untagged_runtime_error(input.to_string())
     }
 }
 
 impl std::convert::From<std::string::FromUtf8Error> for ShellError {
     fn from(input: std::string::FromUtf8Error) -> ShellError {
-        ShellError::untagged_runtime_error(format!("{}", input))
+        ShellError::untagged_runtime_error(input.to_string())
     }
 }
 
 impl std::convert::From<std::str::Utf8Error> for ShellError {
     fn from(input: std::str::Utf8Error) -> ShellError {
-        ShellError::untagged_runtime_error(format!("{}", input))
+        ShellError::untagged_runtime_error(input.to_string())
     }
 }
 
